from setuptools import setup

setup(
    name='grafeat_core_constants',
    version='0.0.1',
    packages=['grafeat_core_constants'],
    install_requires=[],
    url='https://github.com/syntheticastudio/grafeat_plugins',
    author='Ruben Henares',
    author_email='ruben@syntheticastudio.com',
    description='Core plugins for grafeat.',
    keywords=['grafeat', 'plugins']
)

